==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkHyperOctreeDualGridContourFilter.java <==
// java wrapper for vtkHyperOctreeDualGridContourFilter object
//

package vtk;
import vtk.*;

public class vtkHyperOctreeDualGridContourFilter extends vtkPolyDataAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetValue_2(int id0,double id1);
  public void SetValue(int id0,double id1)
    { SetValue_2(id0,id1); }

  private native double GetValue_3(int id0);
  public double GetValue(int id0)
    { return GetValue_3(id0); }

  private native void SetNumberOfContours_4(int id0);
  public void SetNumberOfContours(int id0)
    { SetNumberOfContours_4(id0); }

  private native int GetNumberOfContours_5();
  public int GetNumberOfContours()
    { return GetNumberOfContours_5(); }

  private native void GenerateValues_6(int id0,double id1[]);
  public void GenerateValues(int id0,double id1[])
    { GenerateValues_6(id0,id1); }

  private native void GenerateValues_7(int id0,double id1,double id2);
  public void GenerateValues(int id0,double id1,double id2)
    { GenerateValues_7(id0,id1,id2); }

  private native int GetMTime_8();
  public int GetMTime()
    { return GetMTime_8(); }

  private native void SetLocator_9(vtkIncrementalPointLocator id0);
  public void SetLocator(vtkIncrementalPointLocator id0)
    { SetLocator_9(id0); }

  private native long GetLocator_10();
  public vtkIncrementalPointLocator GetLocator() {
    long temp = GetLocator_10();

    if (temp == 0) return null;
    return (vtkIncrementalPointLocator)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void CreateDefaultLocator_11();
  public void CreateDefaultLocator()
    { CreateDefaultLocator_11(); }

  public vtkHyperOctreeDualGridContourFilter() { super(); }

  public vtkHyperOctreeDualGridContourFilter(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.1.2-2-armv7h.pkg.tar.xz: vtk/vtkHyperOctreeDualGridContourFilter.java <==
// java wrapper for vtkHyperOctreeDualGridContourFilter object
//

package vtk;
import vtk.*;

public class vtkHyperOctreeDualGridContourFilter extends vtkPolyDataAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetValue_2(int id0,double id1);
  public void SetValue(int id0,double id1)
    { SetValue_2(id0,id1); }

  private native double GetValue_3(int id0);
  public double GetValue(int id0)
    { return GetValue_3(id0); }

  private native void SetNumberOfContours_4(int id0);
  public void SetNumberOfContours(int id0)
    { SetNumberOfContours_4(id0); }

  private native int GetNumberOfContours_5();
  public int GetNumberOfContours()
    { return GetNumberOfContours_5(); }

  private native void GenerateValues_6(int id0,double id1[]);
  public void GenerateValues(int id0,double id1[])
    { GenerateValues_6(id0,id1); }

  private native void GenerateValues_7(int id0,double id1,double id2);
  public void GenerateValues(int id0,double id1,double id2)
    { GenerateValues_7(id0,id1,id2); }

  private native int GetMTime_8();
  public int GetMTime()
    { return GetMTime_8(); }

  private native void SetLocator_9(vtkIncrementalPointLocator id0);
  public void SetLocator(vtkIncrementalPointLocator id0)
    { SetLocator_9(id0); }

  private native long GetLocator_10();
  public vtkIncrementalPointLocator GetLocator() {
    long temp = GetLocator_10();

    if (temp == 0) return null;
    return (vtkIncrementalPointLocator)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void CreateDefaultLocator_11();
  public void CreateDefaultLocator()
    { CreateDefaultLocator_11(); }

  public vtkHyperOctreeDualGridContourFilter() { super(); }

  public vtkHyperOctreeDualGridContourFilter(long id) { super(id); }
  public native long   VTKInit();

}
